@@ -3,7 +3,7 @@ IMGO - Process, augment, and balance image data.
 ------------------------------------------------
 UPTOOLS module: 
 
-Last updated: version 2.5.0
+Last updated: version 2.5.1
 
 Classes
 -------
@@ -1294,7 +1294,7 @@ class Image_Dataset:
             "total_images": self.size,
             "splits": splits,
             "images_per_class": imgs_per_class,
-            "image_size": self.dims,
+            "image_shape": self.img_shape,
             "pixel_values": val_ranges,
         }
 
